//
//  AMSDKRenderView.h
//  AliMeetingSDK
//
//  Created by xuanzhen.zjw on 2019/8/15.
//  Copyright © 2019 Alibaba. All rights reserved.
//

#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

//! 视频渲染方式
typedef NS_ENUM(NSInteger, AMSDKScalingType) {
    //! 在保持长宽比的前提下进行缩放，在容器内完整显示
    AMSDKScalingType_ASPECT_FIT,
    //! 在保持长宽比的前提下进行缩放图片，充满容器
    AMSDKScalingType_ASPECT_FILL,
    //! iOS暂不支持，如果设置此值，会当做AMSDKScalingType_ASPECT_FILL处理
    AMSDKScalingType_ASPECT_BALANCED
};

@class AMSDKRenderView;

//! 渲染代理
@protocol AMSDKRendererViewDelegate <NSObject>

@optional

//! 渲染首帧
- (void)onFirstFrameRendered:(AMSDKRenderView *)renderView;

//! 渲染尺寸
- (void)onFrameResolutionChanged:(AMSDKRenderView *)renderView size:(CGSize)size;

//! 渲染帧
- (void)onFrameRendered:(AMSDKRenderView *)renderView;

@end

//! 渲染视图，用于显示视频画面
@interface AMSDKRenderView : UIView

//! 代理
@property (nonatomic, weak) id<AMSDKRendererViewDelegate> renderViewDelegate;

//! 初始化方法
- (instancetype)initWithFrame:(CGRect)frame scalingType:(AMSDKScalingType)scalingType;

//! 初始化方法
- (instancetype)initWithScalingType:(AMSDKScalingType)scalingType;

//! 设置视频渲染方式，见@AMSDKScalingType
- (void)setScalingType:(AMSDKScalingType)scalingType;

//! 设置视频渲染方式，scalingTypeMatchOrientation - 视图与视频方向一致时的渲染方式，scalingTypeMismatchOrientation - 视图与视频方向不一致时的渲染方式  见@AMSDKScalingType
- (void)setScalingTypeMatchOrientation:(AMSDKScalingType)scalingTypeMatchOrientation scalingTypeMismatchOrientation:(AMSDKScalingType)scalingTypeMismatchOrientation;

//! 复用RenderView
- (void)prepareForReuse;

@end

NS_ASSUME_NONNULL_END

